--- loncom/interface/lonprintout.pm 2008/03/10 10:10:18 1.518
+++ loncom/interface/lonprintout.pm 2008/04/04 16:38:34 1.529
@@ -1,7 +1,7 @@
# The LearningOnline Network
# Printout
#
-# $Id: lonprintout.pm,v 1.518 2008/03/10 10:10:18 foxr Exp $
+# $Id: lonprintout.pm,v 1.529 2008/04/04 16:38:34 raeburn Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -38,6 +38,7 @@ use Apache::edit;
use Apache::File();
use Apache::lonnavmaps;
use Apache::admannotations;
+use Apache::lonenc;
use HTTP::Response;
use LONCAPA::map();
@@ -115,7 +116,7 @@ sub annotate {
# the number of times requested by the caller.
# If we still have a proble, no text is appended to the
# output and we set some global variables.
# to indicate to the caller an SSI error occured.
# All of this is supposed to deal with the issues described
# in LonCAPA BZ 5631 see:
# http://bugs.lon-capa.org/show_bug.cgi?id=5631
@@ -131,10 +132,10 @@ sub annotate {
# On success, returns the rendered resource identified by the resource parameter.
# Side Effects:
# The following global variables can be set:
# ssi_error - If an unrecoverable error occured this becomes true.
# It is up to the caller to initialize this to false
# if desired.
# ssi_last_error_resource - If an unrecoverable error occured, this is the value
# of the resource that could not be rendered by the ssi
# call.
# ssi_last_error - The error string fetched from the ssi response
@@ -149,12 +150,29 @@ sub ssi_with_retries {
$ssi_error = 1;
$ssi_last_error_resource = $resource;
$ssi_last_error = $response->code . " " . $response->message;
+ $content='\section*{!!! An error occurred !!!}';
+ &Apache::lonnet::logthis("Error in SSI resource: $resource Error: $ssi_last_error");
}
return $content;
}
+sub get_student_view_with_retries {
+ my ($curresline,$retries,$username,$userdomain,$courseid,$target,$moreenv)=@_;
+
+ my ($content, $response) = &Apache::loncommon::get_student_view_with_retries($curresline,$retries,$username,$userdomain,$courseid,$target,$moreenv);
+ if (!$response->is_success) {
+ $ssi_error = 1;
+ $ssi_last_error_resource = $curresline.' for user '.$username.':'.$userdomain;
+ $ssi_last_error = $response->code . " " . $response->message;
+ $content='\section*{!!! An error occurred !!!}';
+ &Apache::lonnet::logthis("Error in SSI (student view) resource: $curresline Error: $ssi_last_error User: $username:$userdomain");
+ }
+ return $content;
+
+}
+
#
# printf_style_subst item format_string repl
#
@@ -1125,6 +1143,11 @@ sub print_latex_header {
'\usepackage{wrapfig}'.
'\usepackage{picins}\usepackage{calc}'."\n".
'\usepackage[utf8]{inputenc}'."\n".
+ '\usepackage{amsmath}'.
+ '\usepackage{amssymb}'.
+ '\usepackage{amsfonts}'.
+ '\usepackage{amsthm}'.
+ '\usepackage{amscd}'.
'\newenvironment{choicelist}{\begin{list}{}{\setlength{\rightmargin}{0in}'."\n".
'\setlength{\leftmargin}{0.13in}\setlength{\topsep}{0.05in}'."\n".
'\setlength{\itemsep}{0.022in}\setlength{\parsep}{0in}'."\n".
@@ -1471,8 +1494,8 @@ ENDPART
}
if ($helper->{'VARS'}->{'style_file'}=~/\w/) {
- &Apache::lonnet::appenv('construct.style' =>
- $helper->{'VARS'}->{'style_file'});
+ &Apache::lonnet::appenv({'construct.style' =>
+ $helper->{'VARS'}->{'style_file'}});
} elsif ($env{'construct.style'}) {
&Apache::lonnet::delenv('construct\\.style');
}
@@ -1515,7 +1538,7 @@ ENDPART
$rndseed=$helper->{'VARS'}->{'curseed'};
}
$form{'rndseed'}=$rndseed;
- &Apache::lonnet::appenv(%moreenv);
+ &Apache::lonnet::appenv(\%moreenv);
&Apache::lonxml::clear_problem_counter();
@@ -1663,6 +1686,9 @@ ENDPART
my $pbreakresources = keys %page_breaks;
for (my $i=0;$i<=$#master_seq;$i++) {
+ &Apache::lonenc::reset_enc();
+
+
# Note due to document structure, not allowed to put \newpage
# prior to the first resource
@@ -1671,11 +1697,13 @@ ENDPART
$result.="\\newpage\n";
}
}
- my ($sequence,undef,$urlp)=&Apache::lonnet::decode_symb($master_seq[$i]);
+ my ($sequence,$middle_thingy,$urlp)=&Apache::lonnet::decode_symb($master_seq[$i]);
$urlp=&Apache::lonnet::clutter($urlp);
$form{'symb'}=$master_seq[$i];
+
my $assignment=&Apache::lonxml::latex_special_symbols(&Apache::lonnet::gettitle($sequence),'header'); #title of the assignment which contains this problem
+
if ($selectionmade==7) {$helper->{VARS}->{'assignment'}=$assignment;}
if ($i==0) {$prevassignment=$assignment;}
my $texversion='';
@@ -1982,6 +2010,9 @@ ENDPART
$rndseed=$helper->{'VARS'}->{'curseed'};
}
for (my $i=0;$i<=$#list_of_files;$i++) {
+
+ &Apache::lonenc::reset_enc();
+
my $urlp = $list_of_files[$i];
$urlp=~s|//|/|;
if ($urlp=~/\//) {
@@ -2075,98 +2106,68 @@ ENDPART
}
}
-
- # If there's been an unrecoverable SSI error, report it to the user
- # otherwise, we can write the tex file.
- #
-
- if ($ssi_error) {
- my $end_page = &Apache::loncommon::end_page();
- $r->print(<
- I was not able to render one of the print resources ($ssi_last_error_resource)
-due to an unrecoverable error communicating with a server:
-
-$ssi_last_error;
-
-
-I recommend that you try printing again later as this may mean the server was just
-temporarily unavailable, or is down for maintenance. If this error persists, then
-please contact your LonCAPA support folks for assistance and diagnosis.
-
-
-We apologize for the inconvenience.
-
'.
+ &mt('At least one of the resources you chose to print could not be rendered due to an unrecoverable error when communicating with a server:').
+ '
'.$ssi_last_error_resource.'
'.$ssi_last_error.
+ '
'.&mt('You can continue using the link provided below, but make sure to carefully inspect your output file! The errors will be marked in the file.').'
'.
+ &mt('You may be able to reprint the individual resources for which this error occurred, as the issue may be temporary.').
+ '
'.&mt('If the error persists, please contact the [_1] for assistance.',$helpurl).'
'. + &mt('We apologize for the inconvenience.').'
'. + ''.$continue_text.''.$end_page); + } else { $r->print(<
@@ -115,7 +116,7 @@ sub annotate {
# If we still have a proble, no text is appended to the
# output and we set some global variables.
-# to indicate to the caller an SSI error occured.
+# to indicate to the caller an SSI error occurred.
# All of this is supposed to deal with the issues described
# in LonCAPA BZ 5631 see:
@@ -131,10 +132,10 @@ sub annotate {
# Side Effects:
# The following global variables can be set:
-# ssi_error - If an unrecoverable error occured this becomes true.
+# ssi_error - If an unrecoverable error occurred this becomes true.
# It is up to the caller to initialize this to false
# if desired.
@@ -131,10 +132,10 @@ sub annotate {
# It is up to the caller to initialize this to false
# if desired.
-# ssi_last_error_resource - If an unrecoverable error occured, this is the value
+# ssi_last_error_resource - If an unrecoverable error occurred, this is the value
# of the resource that could not be rendered by the ssi
# call.